@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "transferdetailedinfopanel.h"
@@ -39,13 +34,13 @@ namespace Konversation
             m_timeInfo.setupUi(tab);
             addTab(tab, i18n("Details"));
 
-            m_transfer = 0;
+            m_transfer = nullptr;
             m_autoViewUpdateTimer = new QTimer(this);
             m_autoViewUpdateTimer->setInterval(1000);
 
             connect(m_locationInfo.m_urlreqLocation, &KUrlRequester::textChanged, this, &TransferDetailedInfoPanel::slotLocationChanged);
-            connect(Application::instance()->getDccTransferManager(), SIGNAL(fileURLChanged(Konversation::DCC::TransferRecv*)),
-                    this, SLOT(updateView()));  // it's a little rough..
+            connect(Application::instance()->getDccTransferManager(), &TransferManager::fileURLChanged,
+                    this, &TransferDetailedInfoPanel::updateView);  // it's a little rough..
 
             //only enable when needed
             m_locationInfo.m_urlreqLocation->lineEdit()->setReadOnly(true);
@@ -75,8 +70,8 @@ namespace Konversation
             if (m_transfer->getStatus() == Transfer::Transferring)
                 m_autoViewUpdateTimer->start(500);
 
-            connect(item, SIGNAL(statusChanged(Konversation::DCC::Transfer*,int,int)),
-                    this, SLOT(slotTransferStatusChanged(Konversation::DCC::Transfer*,int,int)));
+            connect(item, &Transfer::statusChanged,
+                    this, &TransferDetailedInfoPanel::slotTransferStatusChanged);
 
             updateView();
         }
@@ -95,7 +90,7 @@ namespace Konversation
             // we can't do disconnect( m_item->transfer(), 0, this, 0 ) here
             // because m_item can have been deleted already.
 
-            m_transfer = 0;
+            m_transfer = nullptr;
 
             m_locationInfo.m_urlreqLocation->lineEdit()->setReadOnly(true);
             m_locationInfo.m_urlreqLocation->lineEdit()->setFrame(false);
@@ -159,13 +154,13 @@ namespace Konversation
             {
                 m_locationInfo.m_labelPartner->setText(i18nc("%1=partnerNick, %2=IRC Servername, %3=partnerIP, %4=partnerPort",
                                                              "%1 on %2, %3 (port %4)",
-                                                             m_transfer->getPartnerNick().isEmpty() ? "?" : m_transfer->getPartnerNick(),
+                                                             m_transfer->getPartnerNick().isEmpty() ? QStringLiteral("?") : m_transfer->getPartnerNick(),
                                                              partnerInfoServerName, m_transfer->getPartnerIp(), QString::number(m_transfer->getPartnerPort())));
             }
             else
             {
                 m_locationInfo.m_labelPartner->setText(i18nc("%1 = PartnerNick, %2 = Partner IRC Servername","%1 on %2",
-                                                             m_transfer->getPartnerNick().isEmpty() ? "?" : m_transfer->getPartnerNick(),
+                                                             m_transfer->getPartnerNick().isEmpty() ? QStringLiteral("?") : m_transfer->getPartnerNick(),
                                                              partnerInfoServerName));
             }
 
@@ -184,16 +179,16 @@ namespace Konversation
                 m_timeInfo.m_labelIsResumed->setText(i18nc("no - not a resumed transfer","No"));
 
             // Offered at:
-            m_timeInfo.m_labelTimeOffered->setText(m_transfer->getTimeOffer().toString("hh:mm:ss"));
+            m_timeInfo.m_labelTimeOffered->setText(m_transfer->getTimeOffer().toString(QStringLiteral("hh:mm:ss")));
 
             // Started at:
             if (!m_transfer->getTimeTransferStarted().isNull())
-                m_timeInfo.m_labelTimeStarted->setText(m_transfer->getTimeTransferStarted().toString("hh:mm:ss"));
+                m_timeInfo.m_labelTimeStarted->setText(m_transfer->getTimeTransferStarted().toString(QStringLiteral("hh:mm:ss")));
 
             // Finished at:
             if (!m_transfer->getTimeTransferFinished().isNull())
             {
-                m_timeInfo.m_labelTimeFinished->setText(m_transfer->getTimeTransferFinished().toString("hh:mm:ss"));
+                m_timeInfo.m_labelTimeFinished->setText(m_transfer->getTimeTransferFinished().toString(QStringLiteral("hh:mm:ss")));
             }
 
             updateChangeableView();
@@ -210,14 +205,14 @@ namespace Konversation
             if (m_transfer->getStatus() == Transfer::Transferring)
             {
                 m_locationInfo.m_labelStatus->setText(TransferListModel::getStatusText(m_transfer->getStatus(),
-                                       m_transfer->getType()) + " ( " +
-                                       TransferListModel::getSpeedPrettyText(m_transfer->getCurrentSpeed()) + " )");
+                                       m_transfer->getType()) + QLatin1String(" ( ") +
+                                       TransferListModel::getSpeedPrettyText(m_transfer->getCurrentSpeed()) + QLatin1String(" )"));
             }
             else
             {
                 m_locationInfo.m_labelStatus->setText(m_transfer->getStatusDetail().isEmpty() ?
                                        TransferListModel::getStatusText(m_transfer->getStatus(), m_transfer->getType()) :
-                                       TransferListModel::getStatusText(m_transfer->getStatus(), m_transfer->getType()) + " (" + m_transfer->getStatusDetail() + ')');
+                                       TransferListModel::getStatusText(m_transfer->getStatus(), m_transfer->getType()) + QLatin1String(" (") + m_transfer->getStatusDetail() + QLatin1Char(')'));
             }
 
             // Progress:
@@ -256,7 +251,7 @@ namespace Konversation
 
         void TransferDetailedInfoPanel::slotTransferStatusChanged(Transfer *transfer, int newStatus, int oldStatus)
         {
-            Q_UNUSED(transfer);
+            Q_UNUSED(transfer)
 
             updateView();
             if (newStatus == Transfer::Transferring)
@@ -275,7 +270,7 @@ namespace Konversation
         {
             if (m_transfer &&  m_transfer->getType() == Transfer::Receive)
             {
-                TransferRecv *transfer = static_cast<TransferRecv*>(m_transfer);
+                auto* transfer = static_cast<TransferRecv*>(m_transfer);
                 transfer->setFileURL(QUrl::fromLocalFile(url));
                 updateView();
             }
