@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  RawLog.cpp  -  provides a view to the raw protocol
-  begin:     Tue Mar 18 2003
-  copyright: (C) 2003 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2003 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #include "rawlog.h"
@@ -51,9 +43,9 @@ bool RawLog::closeYourself()
     return true;
 }
 
-bool RawLog::searchView() { return true; }
+bool RawLog::searchView() const { return true; }
 
-bool RawLog::log() { return false; }
+bool RawLog::log() const { return false; }
 
 // The QByteArray implementation of this uses the unintelligent q_strchr for its "exclude" list.
 // Additionally, we need to escape certain values for the IrcView, so rather than letting it loop
